Struct sentry_release_parser::Release[][src]

pub struct Release<'a> { /* fields omitted */ }
Represents a parsed release.

Implementations

impl<'a> Release<'a>[src]

pub fn parse(release: &'a str) -> Result<Release<'a>, InvalidRelease>[src]

Parses a release from a string.

pub fn raw(&self) -> &str[src]

Returns the raw version.

It’s generally better to use to_string which normalizes.

pub fn package(&self) -> Option<&str>[src]

Returns the contained package information.

pub fn version_raw(&self) -> &str[src]

The raw version part of the release.

This is set even if the version part is not a valid version (for instance because it’s a hash).

pub fn version(&self) -> Option<&Version<'a>>[src]

If a parsed version if available returns it.

pub fn build_hash(&self) -> Option<&str>[src]

Returns the build hash if available.

pub fn describe(&self) -> ReleaseDescription<'_>[src]

Returns a short description.

This returns a human readable format that includes an abbreviated name of the release. Typically it will remove the package and it will try to abbreviate build hashes etc.